﻿using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.IO;
using System.Net;
using System.Text;
using System.Web;
using System.Xml;
using System.Xml.Serialization;
using Microsoft.SharePoint;


namespace FormCreation
{
    class Program
    {
        static void Main(string[] args)
        {
            GenerateIPForms();
        }


        static void GenerateIPForms()
        {
            Console.WriteLine("Generating InfoPath Form...");
            string formLibraryUrlPath = ConfigurationManager.AppSettings["Form Library"];
            string formsServer = ConfigurationManager.AppSettings["Forms Server"];
            string solutionVersion = ConfigurationManager.AppSettings["Form Version"];
            string employeeFile = ConfigurationManager.AppSettings["Employee File"];

            byte[] infoPathFormData = null;
            
            using (MemoryStream ms = new MemoryStream())
            {
                using (XmlTextWriter writer = new XmlTextWriter(ms, Encoding.UTF8))
                {
                    // Define the namespace for the form
                    XmlSerializerNamespaces myNamespace = new XmlSerializerNamespaces();
                    myNamespace.Add("my", "http://schemas.microsoft.com/office/infopath/2003/myXSD/2008-11-20T16:28:17");
                    myNamespace.Add("xsi", "http://www.w3.org/2001/XMLSchema-instance");
                    myNamespace.Add("xhtml", "http://www.w3.org/1999/xhtml");

                          
                    writer.WriteStartDocument();
                    // Create the required processing instructions
                    writer.WriteProcessingInstruction(
                    "mso-infoPathSolution",
                    "name=\"urn:schemas-microsoft-com:office:infopath:RegistrationForm:-myXSD-2008-11-20T16-28-17\" solutionVersion=\"" + solutionVersion + "\" productVersion=\"12.0.0.0\" PIVersion=\"1.0.0.0\" href=\"" + "http://morgannet.morganlewis.net/sites/TS/FormServerTemplates/RegistrationForm.xsn\"");
                    writer.WriteProcessingInstruction(
                    "mso-application",
                    "progid=\"InfoPath.Document\" versionProgid=\"InfoPath.Document.2\"");

                    FormCreation.myFields registrationForm = new myFields();

                    //Set form values
                    registrationForm.HasSecondResidence = false;
                    registrationForm.sectionPersonalInformation = new sectionPersonalInformation();
                    registrationForm.sectionPersonalInformation.Name = "Steve";
                            
                    XmlSerializer serializer = new XmlSerializer(typeof(FormCreation.myFields));
                    serializer.Serialize(writer, registrationForm, myNamespace);

                    writer.WriteEndDocument();
                    writer.Flush();
                    writer.Close();
                }

                infoPathFormData = ms.GetBuffer();
                ms.Close();
            }

            // Upload the newly created InfoPath form to SharePoint
            if (infoPathFormData != null && infoPathFormData.Length != 0)
            {
                using (WebClient client = new WebClient())
                {
                    // Set the credentials to be used for upload to SharePoint
                    client.Credentials = CredentialCache.DefaultCredentials;

                    // Upload the newly created form to a SharePoint form library
                    client.UploadData(formLibraryUrlPath + "FormInstance.xml", "PUT", infoPathFormData);

                }
            }

            Console.WriteLine("Form generation complete");
        }

    
    }
}
